@@ -5,7 +5,7 @@
 #  (c) 2013 Jérôme Schneider <mail@jeromeschneider.fr>
 #  All rights reserved
 #
-#  http://baikal-server.com
+#  http://sabre.io/baikal
 #
 #  This script is part of the Baïkal Server project. The Baïkal
 #  Server project is free software; you can redistribute it
@@ -24,5 +24,5 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
-define("BAIKAL_VERSION", "0.4.6");
-define("BAIKAL_HOMEPAGE", "http://baikal-server.com");
+define("BAIKAL_VERSION", "0.6.1");
+define("BAIKAL_HOMEPAGE", "http://sabre.io/baikal/");
