@@ -69,7 +69,7 @@ class PDOBasicAuth extends \Sabre\DAV\Auth\Backend\AbstractBasic {
         if (!count($result)) return false;
 
         $hash = md5($username . ':' . $this->authRealm . ':' . $password);
-        if ($result[0]['digesta1'] == $hash)
+        if ($result[0]['digesta1'] === $hash)
         {
             $this->currentUser = $username;
             return true;
