@@ -5,7 +5,7 @@
 #  (c) 2013 Jérôme Schneider <mail@jeromeschneider.fr>
 #  All rights reserved
 #
-#  http://baikal-server.com
+#  http://sabre.io/baikal
 #
 #  This script is part of the Baïkal Server project. The Baïkal
 #  Server project is free software; you can redistribute it
@@ -89,9 +89,8 @@ class AddressBook extends \Flake\Core\Model\Db {
         ]));
 
         $oMorpho->add(new \Formal\Element\Text([
-            "prop"       => "description",
-            "label"      => "Description",
-            "validation" => "required"
+            "prop"  => "description",
+            "label" => "Description"
         ]));
 
         if ($this->floating()) {
